==> phone_form_field-8.0.0.tar.gz: lib/src/validation/phone_validator.dart <==
import 'package:phone_form_field/phone_form_field.dart';

typedef PhoneNumberInputValidator = String? Function(PhoneNumber? phoneNumber);

class PhoneValidator {
  /// allow to compose several validators
  /// Note that validator list order is important as first
  /// validator failing will return according message.
  static PhoneNumberInputValidator compose(
    List<PhoneNumberInputValidator> validators,
  ) {
    return (valueCandidate) {
      for (var validator in validators) {
        final validatorResult = validator.call(valueCandidate);
        if (validatorResult != null) {
          return validatorResult;
        }
      }
      return null;
    };
  }

  static PhoneNumberInputValidator required({
    /// custom error message
    String? errorText,
  }) {
    return (PhoneNumber? valueCandidate) {
      if (valueCandidate == null || (valueCandidate.nsn.trim().isEmpty)) {
        return errorText ?? 'requiredPhoneNumber';
      }
      return null;
    };
  }

  static PhoneNumberInputValidator invalid({
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) =>
      valid(errorText: errorText, allowEmpty: allowEmpty);

  static PhoneNumberInputValidator valid({
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) {
    
    return (PhoneNumber? valueCandidate) {
      if (valueCandidate == null && !allowEmpty) {
        return errorText ?? 'invalidPhoneNumber';
      }
      if (valueCandidate != null &&
          (!allowEmpty || valueCandidate.nsn.isNotEmpty) &&
          !valueCandidate.isValid()) {
        return errorText ?? 'invalidPhoneNumber';
      }
      return null;
    };
  }

  @Deprecated('use validType, invalid type naming was backward')
  static PhoneNumberInputValidator invalidType(
    /// expected phonetype
    PhoneNumberType expectedType, {
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) =>
      validType(
        expectedType,
        errorText: errorText,
        allowEmpty: allowEmpty,
      );

  static PhoneNumberInputValidator validType(
    /// expected phonetype
    PhoneNumberType expectedType, {
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) {
    final defaultMessage = expectedType == PhoneNumberType.mobile
        ? 'invalidMobilePhoneNumber'
        : 'invalidFixedLinePhoneNumber';
    return (PhoneNumber? valueCandidate) {
      if (valueCandidate != null &&
          (!allowEmpty || valueCandidate.nsn.isNotEmpty) &&
          !valueCandidate.isValid(type: expectedType)) {
        return errorText ?? defaultMessage;
      }
      return null;
    };
  }

  @Deprecated('use validFixedLine, naming was backward')
  static PhoneNumberInputValidator invalidFixedLine({
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) =>
      validFixedLine(errorText: errorText, allowEmpty: allowEmpty);

  /// convenience shortcut method for
  /// invalidType(context, PhoneNumberType.fixedLine, ...)
  static PhoneNumberInputValidator validFixedLine({
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) =>
      validType(
        PhoneNumberType.fixedLine,
        errorText: errorText,
        allowEmpty: allowEmpty,
      );

  @Deprecated('Use validMobile, naming was backward')
  static PhoneNumberInputValidator invalidMobile({
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) =>
      validMobile(
        errorText: errorText,
        allowEmpty: allowEmpty,
      );

  /// convenience shortcut method for
  /// invalidType(context, PhoneNumberType.mobile, ...)
  static PhoneNumberInputValidator validMobile({
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) =>
      validType(
        PhoneNumberType.mobile,
        errorText: errorText,
        allowEmpty: allowEmpty,
      );

  @Deprecated('Use valid country, naming was backward')
  static invalidCountry(
    /// list of valid country isocode
    List<IsoCode> expectedCountries, {
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) =>
      validCountry(
        expectedCountries,
        errorText: errorText,
        allowEmpty: allowEmpty,
      );

  static PhoneNumberInputValidator validCountry(
    /// list of valid country isocode
    List<IsoCode> expectedCountries, {
    /// custom error message
    String? errorText,

    /// determine whether a missing value should be reported as invalid
    bool allowEmpty = true,
  }) {
    return (PhoneNumber? valueCandidate) {
      if (valueCandidate != null &&
          (!allowEmpty || valueCandidate.nsn.isNotEmpty) &&
          !expectedCountries.contains(valueCandidate.isoCode)) {
        return errorText ?? 'invalidCountry';
      }
      return null;
    };
  }

  static PhoneNumberInputValidator get none => (PhoneNumber? valueCandidate) {
        return null;
      };
}

==> phone_form_field-9.0.4.tar.gz: lib/src/validation/phone_validator.dart <==
import 'package:flutter/material.dart';
import 'package:phone_form_field/phone_form_field.dart';

typedef PhoneNumberInputValidator = String? Function(PhoneNumber? phoneNumber);

abstract class PhoneValidator {
  /// allow to compose several validators
  /// Note that validator list order is important as first
  /// validator failing will return according message.
  static PhoneNumberInputValidator compose(
    List<PhoneNumberInputValidator> validators,
  ) {
    return (valueCandidate) {
      for (var validator in validators) {
        final validatorResult = validator.call(valueCandidate);
        if (validatorResult != null) {
          return validatorResult;
        }
      }
      return null;
    };
  }

  static PhoneNumberInputValidator required(
    BuildContext context, {
    /// custom error message
    String? errorText,
  }) {
    return (PhoneNumber? valueCandidate) {
      if (valueCandidate == null || (valueCandidate.nsn.trim().isEmpty)) {
        return errorText ??
            PhoneFieldLocalization.of(context).requiredPhoneNumber;
      }
      return null;
    };
  }

  static PhoneNumberInputValidator valid(
    BuildContext context, {
    /// custom error message
    String? errorText,
  }) {
    return (PhoneNumber? valueCandidate) {
      if (valueCandidate != null &&
          valueCandidate.nsn.isNotEmpty &&
          !valueCandidate.isValid()) {
        return errorText ??
            PhoneFieldLocalization.of(context).invalidPhoneNumber;
      }
      return null;
    };
  }

  static PhoneNumberInputValidator validType(
    BuildContext context,

    /// expected phonetype
    PhoneNumberType expectedType, {
    /// custom error message
    String? errorText,
  }) {
    return (PhoneNumber? valueCandidate) {
      if (valueCandidate != null &&
          valueCandidate.nsn.isNotEmpty &&
          !valueCandidate.isValid(type: expectedType)) {
        if (expectedType == PhoneNumberType.mobile) {
          return errorText ??
              PhoneFieldLocalization.of(context).invalidMobilePhoneNumber;
        } else if (expectedType == PhoneNumberType.fixedLine) {
          return errorText ??
              PhoneFieldLocalization.of(context).invalidFixedLinePhoneNumber;
        }
        return errorText ??
            PhoneFieldLocalization.of(context).invalidPhoneNumber;
      }
      return null;
    };
  }

  /// convenience shortcut method for
  /// invalidType(context, PhoneNumberType.fixedLine, ...)
  static PhoneNumberInputValidator validFixedLine(
    BuildContext context, {
    /// custom error message
    String? errorText,
  }) =>
      validType(
        context,
        PhoneNumberType.fixedLine,
        errorText: errorText,
      );

  /// convenience shortcut method for
  /// invalidType(context, PhoneNumberType.mobile, ...)
  static PhoneNumberInputValidator validMobile(
    BuildContext context, {
    /// custom error message
    String? errorText,
  }) =>
      validType(
        context,
        PhoneNumberType.mobile,
        errorText: errorText,
      );

  static PhoneNumberInputValidator validCountry(
    BuildContext context,

    /// list of valid country isocode
    List<IsoCode> expectedCountries, {
    /// custom error message
    String? errorText,
  }) {
    return (PhoneNumber? valueCandidate) {
      if (valueCandidate != null &&
          (valueCandidate.nsn.isNotEmpty) &&
          !expectedCountries.contains(valueCandidate.isoCode)) {
        return errorText ?? PhoneFieldLocalization.of(context).invalidCountry;
      }
      return null;
    };
  }

  @Deprecated('Use null instead')
  static PhoneNumberInputValidator get none => (PhoneNumber? valueCandidate) {
        return null;
      };
}
